#!/usr/bin/env python
# coding: utf-8

import pandas as pd 
# needs "export PYTHONPATH=<path_to_covid_repo>:$PYTHONPATH"
from utils.sm_annotations import Annotation

# input files needed

### MI-TAB 2.7 file downloaded from the intact webpage for Coronavirus
### https://www.ebi.ac.uk/intact/query/annot:%22dataset:coronavirus%22
mitab_path = "./annot__dat.txt"
#### file download from here: 
#### ftp://ftp.ebi.ac.uk/pub/databases/intact/current/various/mutations.tsv
mutations_path = "./mutations.tsv"


# In[78]:

intact_data = pd.read_csv(mitab_path, sep="\t")


# In[79]:


intact_filtered_A = intact_data[intact_data['Taxid interactor A'] == 'taxid:2697049(SARS-CoV-2)|taxid:2697049(SARS-CoV-2)' ]
intact_filtered_B = intact_data[intact_data['Taxid interactor B'] == 'taxid:2697049(SARS-CoV-2)|taxid:2697049(SARS-CoV-2)' ]


# In[80]:

mutation = pd.read_csv(mutations_path, sep="\t")


# In[81]:


my_intAC = []
for c in intact_filtered_A['Interaction identifier(s)'].unique():

    if c.split("t:")[-1].split("|")[0] not in my_intAC:
        my_intAC.append(c.split("t:")[-1].split("|")[0])


# In[82]:


for c in intact_filtered_B['Interaction identifier(s)'].unique():
    if c.split(":")[-1] not in my_intAC:
        my_intAC.append(c.split(":")[-1])


# In[41]:


mutation_dataframe = pd.DataFrame()
for ac in my_intAC:
    df_test = mutation[mutation['Interaction AC']=='%s'%(ac)]
#     print (type(df_test))
    mutation_dataframe = pd.concat([mutation_dataframe,df_test],axis=0)


# In[57]:



pre_final = mutation_dataframe[["Affected protein AC",
                    "Feature range(s)",
                    "Feature type",
                    "Interaction participants",
                    "Feature short label",
                    "#Feature AC",
                   ]]


# In[59]:


final = pd.DataFrame()


# In[60]:


final['uniprot'] = pre_final["Affected protein AC"].apply( lambda x : x.split(":")[1])


# In[61]:


final['start'] = pre_final["Feature range(s)"].apply(  lambda x : x.split("-")[0])
final['end'] = pre_final["Feature range(s)"].apply(  lambda x : x.split("-")[1])


# In[62]:


final["Interaction participants"] = pre_final["Interaction participants"]
final["Feature short label"] = pre_final["Feature short label"]
final["#Feature AC"] = pre_final["#Feature AC"]


# In[63]:


colors = {'145':'#ff0000', '685':'#fffb00', '986':'#00ff15', '682':'#6600ff', '493':"#0000ff", '501':'#ff9d00'} 


# In[64]:


# final.start.unique()


# In[65]:


final["color"]= final["start"].apply(lambda x : colors[x])


# In[67]:


final["Feature type"] = pre_final["Feature type"]


# In[70]:


annotation = Annotation()


# In[72]:


def split_interaction(x):
    a = x.split("uniprotkb:")
    interactor = []
    for b in a[1:] :
        c = b.split("(protein(")[0]
        interactor.append(c)
    e = "_".join(interactor)
#     print (len(a))
    return e

#     a= x.split(";")[0].split(":")[1]
#     b= x.split(",")[1]
#     return a, b 


# In[73]:


final["Inter"] = final['Interaction participants'].apply(split_interaction)


# In[74]:


for x,y in final.iterrows():
#     print (y["uniprot"],y['start'],y['end'],y['color'],y['Interaction participants'],y['Feature short label'],y['#Feature AC'])
#     print ("%s\t%i\t%i\t%s\t%s\t%s\t%s"%(y["uniprot"],
#                            int(y['start']),
#                            int(y['end']),
#                            y['color'],
# #                            y['Interaction participants'],
#                            y['Feature short label'],
#                            y['#Feature AC'],
#                             y['Inter']
#                           ))
    ann = 'Feature short label:%s,Feature AC:%s,Interaction participants:%s,Feature type:%s'%(  y['Feature short label'],
                           y['#Feature AC'],
                            y['Inter'],y["Feature type"] 
                            )
#     print (ann)
    annotation.add(y["uniprot"],
                   (int(y['start']),int(y['end'])),
                   (y['color']),
                    ann
                   
                          )


# In[75]:


print(annotation)

